@@ -3,5 +3,5 @@ runifcens <- function(n, cens.par) {
 }
 
 rexpcens <- function(n, cens.par) {
-	return( rexp(n=n, rate=cens.par) )
+	return( rexp(n=n, rate=1/cens.par) )
 }
